#include <iostream>

#include <zypp/ZYpp.h>
#include <zypp/ZYppFactory.h>
#include <zypp/PathInfo.h>
#include <zypp/Capability.h>
#include <zypp/Package.h>

#include <zypp/RepoManager.h>
#include <zypp/media/MediaManager.h>
#include <zypp/Resolvable.h>
#include <zypp/ResPool.h>
#include <zypp/Repository.h>
#include <zypp/RepoManager.h>
#include <zypp/RepoInfo.h>
#include <zypp/repo/RepoException.h>
#include <zypp/target/rpm/RpmException.h>
#include <zypp/parser/ParseException.h>
#include <zypp/Pathname.h>
#include <zypp/sat/Pool.h>
#include <zypp/target/rpm/RpmDb.h>
#include <zypp/target/rpm/RpmHeader.h>
#include <zypp/target/rpm/librpmDb.h>
#include <zypp/base/LogControl.h>
#include <zypp/base/String.h>
#include <zypp/repo/PackageProvider.h>
#include <zypp/base/Logger.h>
#include <zypp/PoolQuery.h>
#include <zypp/ui/Selectable.h>
#include <zypp/Pattern.h>
using namespace::std;
using namespace zypp;

zypp::ZYpp::Ptr zyppPtr = zypp::ZYppFactory::instance().getZYpp();

void zypp_build_pool()
{
    zypp::Pathname sysRoot( "/" );
    zyppPtr->initializeTarget( sysRoot, false );
    zyppPtr->target()->load();

    zypp::sat::Pool pool = zypp::sat::Pool::instance ();
    zypp::RepoManager manager;
    std::list <zypp::RepoInfo> repos;
    repos = std::list<zypp::RepoInfo>(manager.repoBegin(),manager.repoEnd());

    bool force = false;
    int i = 0;
    for (std::list <zypp::RepoInfo>::iterator it = repos.begin(); it != repos.end(); it++, i++) {
        zypp::RepoInfo repo (*it);
        // Erase old solv file
        pool.reposErase(repo.alias ());
        cout << "refresh repo :" <<repo.alias () <<endl;
        // Refreshing metadata
        manager.refreshMetadata (repo, zypp::RepoManager::RefreshIfNeededIgnoreDelay);
        manager.buildCache (repo, zypp::RepoManager::BuildIfNeeded);
        manager.loadFromCache (repo);
    }
}

int main(int argc, char **argv) 
{
    zypp_build_pool();

    zypp::ResPool respool = zyppPtr->pool ();
    PoolQuery q;
    q.addKind(ResKind::pattern);
    q.addAttribute(sat::SolvAttr::name, "Tablet");
    q.setMatchExact();
    if (q.empty())
        cout << "\npattern netbook not found" << endl;
    else {
        ui::Selectable::constPtr s = *q.selectableBegin();
        const ui::Selectable & x = *s;
        const PoolItem & pool_item = x.theObj();
        cout << "here.." <<endl;
        Pattern::constPtr pattern = asKind<Pattern>(pool_item.resolvable());
        Pattern::Contents contents = pattern->contents();
        for_(sit, contents.selectableBegin(), contents.selectableEnd()) {
            const ui::Selectable & s = **sit;
            if (s.kind().asString() == "package")
                cout << s.name() <<endl;
        }
    }
    return EXIT_SUCCESS;
}
